==> haskell-doctest-exitcode-stdio-0.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-exitcode-stdio
version:              0.0
visibility:           public
id:                   doctest-exitcode-stdio-0.0-6eiZJbHSVM5IdbmaJytZ7H
key:                  doctest-exitcode-stdio-0.0-6eiZJbHSVM5IdbmaJytZ7H
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  2cd4d24d9a3ba23197b048ff22c84914
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:          /usr/lib/ghc-9.0.1/site-local/doctest-exitcode-stdio-0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/doctest-exitcode-stdio-0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/doctest-exitcode-stdio-0.0

hs-libraries:         HSdoctest-exitcode-stdio-0.0-6eiZJbHSVM5IdbmaJytZ7H
depends:
    QuickCheck-2.14.2-4xShtyX33BN5pkZj6nk754 base-4.15.0.0
    doctest-lib-0.1-KkYFPgyxYmQ4oujE28nmhc transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-exitcode-stdio-0.0-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-exitcode-stdio
version:              0.0
visibility:           public
id:                   doctest-exitcode-stdio-0.0-8nFmxK9VnDrKlgphH7b4s0
key:                  doctest-exitcode-stdio-0.0-8nFmxK9VnDrKlgphH7b4s0
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  83cd78bc44f4fe43f7cdb04f7321845f
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:          /usr/lib/ghc-9.0.1/site-local/doctest-exitcode-stdio-0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/doctest-exitcode-stdio-0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/doctest-exitcode-stdio-0.0

hs-libraries:         HSdoctest-exitcode-stdio-0.0-8nFmxK9VnDrKlgphH7b4s0
depends:
    QuickCheck-2.14.2-D1tDsT83VTn5yrYWDvR6kA base-4.15.0.0
    doctest-lib-0.1-KkYFPgyxYmQ4oujE28nmhc transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
